clc;
clear all; 

%Load dataset2
G00_2 = load('G00_2');
singlephase_2 = load('singlephase_2');
twophase_2 = load('twophase_2');
twophase2_2 = load('twophase2_2');
twophase3_2 = load('twophase3_2');

%Load models
load('GasFlowModel8InputsLinearNorm');
load('GasFlowModel8InputsZscoreNorm');
load('OilFlowModel7InputsLinearNorm');
load('OilFlowModel7InputsZscoreNorm');
load('WatFlowModel7InputsLinearNorm');
load('WatFlowModel7InputsZscoreNorm');
load('TotFlowModel7InputsLinearNorm');
load('TotFlowModel7InputsZscoreNorm');
load('GasFlowDelayModel5InputsZscoreNorm');
load('GasFlowDelayModel8InputsZscoreNorm');
load('TotFlowDelayModel7InputsZscoreNorm');
load('TotFlowDelayModel5InputsZscoreNorm');
load('WatFlowDelayModel7InputsZscoreNorm');
load('WatFlowDelayModel5InputsZscoreNorm');
load('OilFlowDelayModel7InputsZscoreNorm');
load('OilFlowDelayModel5InputsZscoreNorm');

%Background noise of accelerometers in dataset 2
XI1_noise_2 = rms([singlephase_2.background_noise(:,21); twophase_2.background_noise(:,21)]);
XI2_noise_2 = rms([singlephase_2.background_noise(:,22); twophase_2.background_noise(:,22)]);
XI3_noise_2 = rms([singlephase_2.background_noise(:,23); twophase_2.background_noise(:,23)]);
XI4_noise_2 = rms([singlephase_2.background_noise(:,24); twophase_2.background_noise(:,24)]);

%Merging into one dataset for training and one for testing 
training_2 = [twophase_2.training_GO; twophase_2.training_GW; twophase_2.training_OW; twophase2_2.dataset_training; twophase3_2.dataset_training];
testing_2 = [twophase_2.testing_GO; twophase_2.testing_GW; twophase_2.testing_OW; twophase2_2.dataset_testing; twophase3_2.dataset_testing];

%Soft sensors in dataset 2
dP_Train_2 = training_2(:,6) - training_2(:,20);
dP_Test_2 = testing_2(:,6) - testing_2(:,20);
dT_Train_2 = training_2(:,19) - training_2(:,5);
dT_Test_2 = testing_2(:,19) - testing_2(:,5);
Qtot_Train_2 = training_2(:,25) + training_2(:,26) + training_2(:,27);
Qtot_Test_2 = testing_2(:,25) + testing_2(:,26) + testing_2(:,27);

%Adjust for background noise on accelerometers and include all relevant inputs
dataTrainAdj_2 = [training_2(:,1:20) (training_2(:,21)-XI1_noise_2) (training_2(:,22)-XI2_noise_2) (training_2(:,23)-XI3_noise_2) (training_2(:,24)-XI4_noise_2) training_2(:,25:27) Qtot_Train_2 dP_Train_2 dT_Train_2];
dataTestAdj_2 = [testing_2(:,1:20) (testing_2(:,21)-XI1_noise_2) (testing_2(:,22)-XI2_noise_2) (testing_2(:,23)-XI3_noise_2) (testing_2(:,24)-XI4_noise_2) testing_2(:,25:27) Qtot_Test_2 dP_Test_2 dT_Test_2];

%Normalize dataset 2
dataMax_2 = max([dataTrainAdj_2; dataTestAdj_2]);
dataMin_2 = min([dataTrainAdj_2; dataTestAdj_2]);
trainLinear_2 = (dataTrainAdj_2 - dataMin_2)./(dataMax_2 - dataMin_2); 
testLinear_2 = (dataTestAdj_2 - dataMin_2)./(dataMax_2 - dataMin_2); 
trainZscore_2 = zscore(dataTrainAdj_2);
testZscore_2 = zscore(dataTestAdj_2);

%-----------------------------------------------------------------------------------------------------------------------------------------------------------------------

%Gas flow model with inputs from 'Density Krohn3', 'dp 4m straight','dp 2 Venturi 2', accelerometers and delta temperature
Qg_Train8InputsLinear_2 = [trainLinear_2(:,10) trainLinear_2(:,11) trainLinear_2(:,18) trainLinear_2(:,21) trainLinear_2(:,22) trainLinear_2(:,23) trainLinear_2(:,24) trainLinear_2(:,30)];
Qg_Test8InputsLinear_2 = [testLinear_2(:,10) testLinear_2(:,11) testLinear_2(:,18) testLinear_2(:,21) testLinear_2(:,22) testLinear_2(:,23) testLinear_2(:,24) testLinear_2(:,30)];
Qg_Train8InputsZscore_2 = [trainZscore_2(:,10) trainZscore_2(:,11) trainZscore_2(:,18) trainZscore_2(:,21) trainZscore_2(:,22) trainZscore_2(:,23) trainZscore_2(:,24) trainZscore_2(:,30)];
Qg_Test8InputsZscore_2 = [testZscore_2(:,10) testZscore_2(:,11) testZscore_2(:,18) testZscore_2(:,21) testZscore_2(:,22) testZscore_2(:,23) testZscore_2(:,24) testZscore_2(:,30)];

%Gas flow model with input from acoustic emission sensors and 'dp 2 Venturi 2'
Qg_Train5InputsZscore_2 = [trainZscore_2(:,18) trainZscore_2(:,21) trainZscore_2(:,22) trainZscore_2(:,23) trainZscore_2(:,24)];
Qg_Test5InputsZscore_2 = [testZscore_2(:,18) testZscore_2(:,21) testZscore_2(:,22) testZscore_2(:,23) testZscore_2(:,24)];

%Gas flow model output
Qg_Train_2 = [dataTrainAdj_2(:,25)];
Qg_Test_2 = [dataTestAdj_2(:,25)];

%-----------------------------------------------------------------------------------------------------------------------------------------------------------------------

%Water flow estimation model with 'Density Krohn3', 'dp 4m straight', 'dp 1 Venturi 2', accelerometers and delta temperature
Qw_Train7InputsLinear_2 = [trainLinear_2(:,10) trainLinear_2(:,11) trainLinear_2(:,21) trainLinear_2(:,22) trainLinear_2(:,23) trainLinear_2(:,24) trainLinear_2(:,30)];
Qw_Test7InputsLinear_2 = [testLinear_2(:,10) testLinear_2(:,11) testLinear_2(:,21) testLinear_2(:,22) testLinear_2(:,23) testLinear_2(:,24) testLinear_2(:,30)];
Qw_Train7InputsZscore_2 = [trainZscore_2(:,10) trainZscore_2(:,11) trainZscore_2(:,21) trainZscore_2(:,22) trainZscore_2(:,23) trainZscore_2(:,24) trainZscore_2(:,30)];
Qw_Test7InputsZscore_2 = [testZscore_2(:,10) testZscore_2(:,11) testZscore_2(:,21) testZscore_2(:,22) testZscore_2(:,23) testZscore_2(:,24) testZscore_2(:,30)];

%Water flow model with with input from acoustic emission sensors and 'dp 1 Venturi 2'
Qw_Train5InputsZscore_2 = [trainZscore_2(:,17) trainZscore_2(:,21) trainZscore_2(:,22) trainZscore_2(:,23) trainZscore_2(:,24)];
Qw_Test5InputsZscore_2 = [testZscore_2(:,17) testZscore_2(:,21) testZscore_2(:,22) testZscore_2(:,23) testZscore_2(:,24)];

%Water flow model output
Qw_Train_2 = [dataTrainAdj_2(:,26)];
Qw_Test_2 = [dataTestAdj_2(:,26)];

%------------------------------------------------------------------------------------------------------------------------------------------------------------------------

%Oil flow estimation model with 'dp 4m straight', 'dp 1 Venturi 2', accelerometers and delta temperature
Qo_Train7InputsLinear_2 = [trainLinear_2(:,11) trainLinear_2(:,17) trainLinear_2(:,21) trainLinear_2(:,22) trainLinear_2(:,23) trainLinear_2(:,24) trainLinear_2(:,30)];
Qo_Test7InputsLinear_2 = [testLinear_2(:,11) testLinear_2(:,17) testLinear_2(:,21) testLinear_2(:,22) testLinear_2(:,23) testLinear_2(:,24) testLinear_2(:,30)];
Qo_Train7InputsZscore_2 = [trainZscore_2(:,11) trainZscore_2(:,17) trainZscore_2(:,21) trainZscore_2(:,22) trainZscore_2(:,23) trainZscore_2(:,24) trainZscore_2(:,30)];
Qo_Test7InputsZscore_2 = [testZscore_2(:,11) testZscore_2(:,17) testZscore_2(:,21) testZscore_2(:,22) testZscore_2(:,23) testZscore_2(:,24) testZscore_2(:,30)];

%Oil flow model with with input from acoustic emission sensors and 'dp 1 Venturi 2'
Qo_Train5InputsZscore_2 = [trainZscore_2(:,17) trainZscore_2(:,21) trainZscore_2(:,22) trainZscore_2(:,23) trainZscore_2(:,24)];
Qo_Test5InputsZscore_2 = [testZscore_2(:,17) testZscore_2(:,21) testZscore_2(:,22) testZscore_2(:,23) testZscore_2(:,24)];

%Oil flow model output
Qo_Train_2 = [dataTrainAdj_2(:,27)];
Qo_Test_2 = [dataTestAdj_2(:,27)];

%------------------------------------------------------------------------------------------------------------------------------------------------------------------------

%Total flow estimation model with 'dp 4m straight', 'dp 1 Venturi 2', accelerometers and delta temperature
Qtot_Train7InputsLinear_2 = [trainLinear_2(:,11) trainLinear_2(:,17) trainLinear_2(:,21) trainLinear_2(:,22) trainLinear_2(:,23) trainLinear_2(:,24) trainLinear_2(:,30)];
Qtot_Test7InputsLinear_2 = [testLinear_2(:,11) testLinear_2(:,17) testLinear_2(:,21) testLinear_2(:,22) testLinear_2(:,23) testLinear_2(:,24) testLinear_2(:,30)];
Qtot_Train7InputsZscore_2 = [trainZscore_2(:,11) trainZscore_2(:,17) trainZscore_2(:,21) trainZscore_2(:,22) trainZscore_2(:,23) trainZscore_2(:,24) trainZscore_2(:,30)];
Qtot_Test7InputsZscore_2 = [testZscore_2(:,11) testZscore_2(:,17) testZscore_2(:,21) testZscore_2(:,22) testZscore_2(:,23) testZscore_2(:,24) testZscore_2(:,30)];

%Total flow estimation model with with input from acoustic emission sensors and 'dp 1 Venturi 2'
Qtot_Train5InputsZscore_2 = [trainZscore_2(:,17) trainZscore_2(:,21) trainZscore_2(:,22) trainZscore_2(:,23) trainZscore_2(:,24)];
Qtot_Test5InputsZscore_2 = [testZscore_2(:,17) testZscore_2(:,21) testZscore_2(:,22) testZscore_2(:,23) testZscore_2(:,24)];

%Total flow model output
Qtot_Train_2 = dataTrainAdj_2(:,28);
Qtot_Test_2 = dataTestAdj_2(:,28);

%------------------------------------------------------------------------------------------------------------------------------------------------------------------------

%Close loop on NARX neural networks
gasNARXModel8InputsLinearClosed = closeloop(GasFlowModel8InputsLinearNorm.Network);
gasNARXModel8InputsZscoreClosed = closeloop(GasFlowModel8InputsZscoreNorm.Network);
oilNARXModel7InputsLinearClosed = closeloop(OilFlowModel7InputsLinearNorm.Network);
oilNARXModel7InputsZscoreClosed = closeloop(OilFlowModel7InputsZscoreNorm.Network);
watNARXModel7InputsLinearClosed = closeloop(WatFlowModel7InputsLinearNorm.Network);
watNARXModel7InputsZscoreClosed = closeloop(WatFlowModel7InputsZscoreNorm.Network);
totNARXModel7InputsLinearClosed = closeloop(TotFlowModel7InputsLinearNorm.Network);
totNARXModel7InputsZscoreClosed = closeloop(TotFlowModel7InputsZscoreNorm.Network);

%Estimate gas flow with a NARX model.
simGasNARXModelTrain8InputsLinearOpen_2 = seq2con(SimulateNARXNetwork(GasFlowModel8InputsLinearNorm.Network, con2seq(Qg_Train8InputsLinear_2'), con2seq(Qg_Train_2')));
simGasNARXModelTrain8InputsLinearClosed_2 = seq2con(SimulateNARXNetwork(gasNARXModel8InputsLinearClosed, con2seq(Qg_Train8InputsLinear_2'), con2seq(Qg_Train_2')));
simGasNARXModelTest8InputsLinearOpen_2 = seq2con(SimulateNARXNetwork(GasFlowModel8InputsLinearNorm.Network, con2seq(Qg_Test8InputsLinear_2'), con2seq(Qg_Test_2')));
simGasNARXModelTest8InputsLinearClosed_2 = seq2con(SimulateNARXNetwork(gasNARXModel8InputsLinearClosed, con2seq(Qg_Test8InputsLinear_2'), con2seq(Qg_Test_2')));
simGasNARXModelTrain8InputsZscoreOpen_2 = seq2con(SimulateNARXNetwork(GasFlowModel8InputsZscoreNorm.Network, con2seq(Qg_Train8InputsZscore_2'), con2seq(Qg_Train_2')));
simGasNARXModelTrain8InputsZscoreClosed_2 = seq2con(SimulateNARXNetwork(gasNARXModel8InputsZscoreClosed, con2seq(Qg_Train8InputsZscore_2'), con2seq(Qg_Train_2')));
simGasNARXModelTest8InputsZscoreOpen_2 = seq2con(SimulateNARXNetwork(GasFlowModel8InputsZscoreNorm.Network, con2seq(Qg_Test8InputsZscore_2'), con2seq(Qg_Test_2')));
simGasNARXModelTest8InputsZscoreClosed_2 = seq2con(SimulateNARXNetwork(gasNARXModel8InputsZscoreClosed, con2seq(Qg_Test8InputsZscore_2'), con2seq(Qg_Test_2')));

%Estimate gas flow with a delay model
simGasInputOutputModelTrain8InputsZscore_2 = seq2con(SimulateInputOutputNetwork(GasFlowDelayModel8InputsZscoreNorm.Network, con2seq(Qg_Train8InputsZscore_2'), con2seq(Qg_Train_2')));
simGasInputOutputModelTest8InputsZscore_2 = seq2con(SimulateInputOutputNetwork(GasFlowDelayModel8InputsZscoreNorm.Network, con2seq(Qg_Test8InputsZscore_2'), con2seq(Qg_Test_2')));
simGasInputOutputModelTrain5InputsZscore_2 = seq2con(SimulateInputOutputNetwork(GasFlowDelayModel5InputsZscoreNorm.Network, con2seq(Qg_Train5InputsZscore_2'), con2seq(Qg_Train_2')));
simGasInputOutputModelTest5InputsZscore_2 = seq2con(SimulateInputOutputNetwork(GasFlowDelayModel5InputsZscoreNorm.Network, con2seq(Qg_Test5InputsZscore_2'), con2seq(Qg_Test_2')));

%Estimate oil flow with a NARX model
simOilNARXModelTrain7InputsLinearOpen_2 = seq2con(SimulateNARXNetwork(OilFlowModel7InputsLinearNorm.Network, con2seq(Qo_Train7InputsLinear_2'), con2seq(Qo_Train_2')));
simOilNARXModelTrain7InputsLinearClosed_2 = seq2con(SimulateNARXNetwork(oilNARXModel7InputsLinearClosed, con2seq(Qo_Train7InputsLinear_2'), con2seq(Qo_Train_2')));
simOilNARXModelTest7InputsLinearOpen_2 = seq2con(SimulateNARXNetwork(OilFlowModel7InputsLinearNorm.Network, con2seq(Qo_Test7InputsLinear_2'), con2seq(Qo_Test_2')));
simOilNARXModelTest7InputsLinearClosed_2 = seq2con(SimulateNARXNetwork(oilNARXModel7InputsLinearClosed, con2seq(Qo_Test7InputsLinear_2'), con2seq(Qo_Test_2')));
simOilNARXModelTrain7InputsZscoreOpen_2 = seq2con(SimulateNARXNetwork(OilFlowModel7InputsZscoreNorm.Network, con2seq(Qo_Train7InputsZscore_2'), con2seq(Qo_Train_2')));
simOilNARXModelTrain7InputsZscoreClosed_2 = seq2con(SimulateNARXNetwork(oilNARXModel7InputsZscoreClosed, con2seq(Qo_Train7InputsZscore_2'), con2seq(Qo_Train_2')));
simOilNARXModelTest7InputsZscoreOpen_2 = seq2con(SimulateNARXNetwork(OilFlowModel7InputsZscoreNorm.Network, con2seq(Qo_Test7InputsZscore_2'), con2seq(Qo_Test_2')));
simOilNARXModelTest7InputsZscoreClosed_2 = seq2con(SimulateNARXNetwork(oilNARXModel7InputsZscoreClosed, con2seq(Qo_Test7InputsZscore_2'), con2seq(Qo_Test_2')));

%Estimate oil flow with a delay model
simOilInputOutputModelTrain7InputsZscore_2 = seq2con(SimulateInputOutputNetwork(OilFlowDelayModel7InputsZscoreNorm.Network, con2seq(Qo_Train7InputsZscore_2'), con2seq(Qo_Train_2')));
simOilInputOutputModelTest7InputsZscore_2 = seq2con(SimulateInputOutputNetwork(OilFlowDelayModel7InputsZscoreNorm.Network, con2seq(Qo_Test7InputsZscore_2'), con2seq(Qo_Test_2')));
simOilInputOutputModelTrain5InputsZscore_2 = seq2con(SimulateInputOutputNetwork(OilFlowDelayModel5InputsZscoreNorm.Network, con2seq(Qo_Train5InputsZscore_2'), con2seq(Qo_Train_2')));
simOilInputOutputModelTest5InputsZscore_2 = seq2con(SimulateInputOutputNetwork(OilFlowDelayModel5InputsZscoreNorm.Network, con2seq(Qo_Test5InputsZscore_2'), con2seq(Qo_Test_2')));

%Estimate wat flow with a NARX model
simWatNARXModelTrain7InputsLinearOpen_2 = seq2con(SimulateNARXNetwork(WatFlowModel7InputsLinearNorm.Network, con2seq(Qw_Train7InputsLinear_2'), con2seq(Qw_Train_2')));
simWatNARXModelTrain7InputsLinearClosed_2 = seq2con(SimulateNARXNetwork(watNARXModel7InputsLinearClosed, con2seq(Qw_Train7InputsLinear_2'), con2seq(Qw_Train_2')));
simWatNARXModelTest7InputsLinearOpen_2 = seq2con(SimulateNARXNetwork(WatFlowModel7InputsLinearNorm.Network, con2seq(Qw_Test7InputsLinear_2'), con2seq(Qw_Test_2')));
simWatNARXModelTest7InputsLinearClosed_2 = seq2con(SimulateNARXNetwork(watNARXModel7InputsLinearClosed, con2seq(Qw_Test7InputsLinear_2'), con2seq(Qw_Test_2')));
simWatNARXModelTrain7InputsZscoreOpen_2 = seq2con(SimulateNARXNetwork(WatFlowModel7InputsZscoreNorm.Network, con2seq(Qw_Train7InputsZscore_2'), con2seq(Qw_Train_2')));
simWatNARXModelTrain7InputsZscoreClosed_2 = seq2con(SimulateNARXNetwork(watNARXModel7InputsZscoreClosed, con2seq(Qw_Train7InputsZscore_2'), con2seq(Qw_Train_2')));
simWatNARXModelTest7InputsZscoreOpen_2 = seq2con(SimulateNARXNetwork(WatFlowModel7InputsZscoreNorm.Network, con2seq(Qw_Test7InputsZscore_2'), con2seq(Qw_Test_2')));
simWatNARXModelTest7InputsZscoreClosed_2 = seq2con(SimulateNARXNetwork(watNARXModel7InputsZscoreClosed, con2seq(Qw_Test7InputsZscore_2'), con2seq(Qw_Test_2')));

%Estimate wat flow with a delay model
simWatInputOutputModelTrain7InputsZscore_2 = seq2con(SimulateInputOutputNetwork(WatFlowDelayModel7InputsZscoreNorm.Network, con2seq(Qw_Train7InputsZscore_2'), con2seq(Qw_Train_2')));
simWatInputOutputModelTest7InputsZscore_2 = seq2con(SimulateInputOutputNetwork(WatFlowDelayModel7InputsZscoreNorm.Network, con2seq(Qw_Test7InputsZscore_2'), con2seq(Qw_Test_2')));
simWatInputOutputModelTrain5InputsZscore_2 = seq2con(SimulateInputOutputNetwork(WatFlowDelayModel5InputsZscoreNorm.Network, con2seq(Qw_Train5InputsZscore_2'), con2seq(Qw_Train_2')));
simWatInputOutputModelTest5InputsZscore_2 = seq2con(SimulateInputOutputNetwork(WatFlowDelayModel5InputsZscoreNorm.Network, con2seq(Qw_Test5InputsZscore_2'), con2seq(Qw_Test_2')));

%Estimate total flow with a NARX model
simTotNARXModelTrain7InputsLinearOpen_2 = seq2con(SimulateNARXNetwork(TotFlowModel7InputsLinearNorm.Network, con2seq(Qtot_Train7InputsLinear_2'), con2seq(Qtot_Train_2')));
simTotNARXModelTrain7InputsLinearClosed_2 = seq2con(SimulateNARXNetwork(totNARXModel7InputsLinearClosed, con2seq(Qtot_Train7InputsLinear_2'), con2seq(Qtot_Train_2')));
simTotNARXModelTest7InputsLinearOpen_2 = seq2con(SimulateNARXNetwork(TotFlowModel7InputsLinearNorm.Network, con2seq(Qtot_Test7InputsLinear_2'), con2seq(Qtot_Test_2')));
simTotNARXModelTest7InputsLinearClosed_2 = seq2con(SimulateNARXNetwork(totNARXModel7InputsLinearClosed, con2seq(Qtot_Test7InputsLinear_2'), con2seq(Qtot_Test_2')));
simTotNARXModelTrain7InputsZscoreOpen_2 = seq2con(SimulateNARXNetwork(TotFlowModel7InputsZscoreNorm.Network, con2seq(Qtot_Train7InputsZscore_2'), con2seq(Qtot_Train_2')));
simTotNARXModelTrain7InputsZscoreClosed_2 = seq2con(SimulateNARXNetwork(totNARXModel7InputsZscoreClosed, con2seq(Qtot_Train7InputsZscore_2'), con2seq(Qtot_Train_2')));
simTotNARXModelTest7InputsZscoreOpen_2 = seq2con(SimulateNARXNetwork(TotFlowModel7InputsZscoreNorm.Network, con2seq(Qtot_Test7InputsZscore_2'), con2seq(Qtot_Test_2')));
simTotNARXModelTest7InputsZscoreClosed_2 = seq2con(SimulateNARXNetwork(totNARXModel7InputsZscoreClosed, con2seq(Qtot_Test7InputsZscore_2'), con2seq(Qtot_Test_2')));

%Estimate total flow with a delay model
simTotInputOutputModelTrain7InputsZscore_2 = seq2con(SimulateInputOutputNetwork(TotFlowDelayModel7InputsZscoreNorm.Network, con2seq(Qtot_Train7InputsZscore_2'), con2seq(Qtot_Train_2')));
simTotInputOutputModelTest7InputsZscore_2 = seq2con(SimulateInputOutputNetwork(TotFlowDelayModel7InputsZscoreNorm.Network, con2seq(Qtot_Test7InputsZscore_2'), con2seq(Qtot_Test_2')));
simTotInputOutputModelTrain5InputsZscore_2 = seq2con(SimulateInputOutputNetwork(TotFlowDelayModel5InputsZscoreNorm.Network, con2seq(Qtot_Train5InputsZscore_2'), con2seq(Qtot_Train_2')));
simTotInputOutputModelTest5InputsZscore_2 = seq2con(SimulateInputOutputNetwork(TotFlowDelayModel5InputsZscoreNorm.Network, con2seq(Qtot_Test5InputsZscore_2'), con2seq(Qtot_Test_2')));

%Calculated water cut from estimated flow
WLR_Train_2 = Qw_Train_2 ./ (Qw_Train_2 + Qo_Train_2);
WLR_Train_2(isnan(WLR_Train_2)) = 0;
WLR_Test_2 = Qw_Test_2 ./ (Qw_Test_2 + Qo_Test_2);
WLR_Test_2(isnan(WLR_Test_2)) = 0;
WLR_simInputOutputModelTrain7InputsZscore_2 = simWatInputOutputModelTrain7InputsZscore_2{1, 1}' ./ (simWatInputOutputModelTrain7InputsZscore_2{1, 1}' + simOilInputOutputModelTrain7InputsZscore_2{1, 1}');
WLR_simInputOutputModelTrain7InputsZscore_2(isnan(WLR_simInputOutputModelTrain7InputsZscore_2)) = 0;
WLR_simInputOutputModelTrain5InputsZscore_2 = simWatInputOutputModelTrain5InputsZscore_2{1, 1}' ./ (simWatInputOutputModelTrain5InputsZscore_2{1, 1}' + simOilInputOutputModelTrain5InputsZscore_2{1, 1}');
WLR_simInputOutputModelTrain5InputsZscore_2(isnan(WLR_simInputOutputModelTrain5InputsZscore_2)) = 0;
WLR_simInputOutputOutputModelTest7InputsZscore_2 = simWatInputOutputModelTest7InputsZscore_2{1, 1}' ./ (simWatInputOutputModelTest7InputsZscore_2{1, 1}' + simOilInputOutputModelTest7InputsZscore_2{1, 1}');
WLR_simInputOutputOutputModelTest7InputsZscore_2(isnan(WLR_simInputOutputOutputModelTest7InputsZscore_2)) = 0;
WLR_simInputOutputModelTest5InputsZscore_2 = simWatInputOutputModelTest5InputsZscore_2{1, 1}' ./ (simWatInputOutputModelTest5InputsZscore_2{1, 1}' + simOilInputOutputModelTest5InputsZscore_2{1, 1}');
WLR_simInputOutputModelTest5InputsZscore_2(isnan(WLR_simInputOutputModelTest5InputsZscore_2)) = 0;

%Calculated gas void fraction from estimated flow
GV_Train_2 = Qg_Train_2 ./ Qtot_Train_2;
GV_Train_2(isnan(GV_Train_2)) = 0;
GV_Test_2 = Qg_Test_2 ./  Qtot_Test_2;
GV_Test_2(isnan(GV_Test_2)) = 0;
GV_simInputOutputModelTrain7InputsZscore_2 = simGasInputOutputModelTrain8InputsZscore_2{1, 1}' ./ simTotInputOutputModelTrain7InputsZscore_2{1, 1}';
GV_simInputOutputModelTrain7InputsZscore_2(isnan(GV_simInputOutputModelTrain7InputsZscore_2)) = 0;
GV_simInputOutputModelTrain5InputsZscore_2 = simGasInputOutputModelTrain5InputsZscore_2{1, 1}' ./ simTotInputOutputModelTrain5InputsZscore_2{1, 1}';
GV_simInputOutputModelTrain5InputsZscore_2(isnan(GV_simInputOutputModelTrain5InputsZscore_2)) = 0;
GV_simInputOutputModelTest7InputsZscore_2 = simGasInputOutputModelTest8InputsZscore_2{1, 1}' ./ simTotInputOutputModelTest7InputsZscore_2{1, 1}';
GV_simInputOutputModelTest7InputsZscore_2(isnan(GV_simInputOutputModelTest7InputsZscore_2)) = 0;
GV_simInputOutputModelTest5InputsZscore_2 = simGasInputOutputModelTest5InputsZscore_2{1, 1}' ./  simTotInputOutputModelTest5InputsZscore_2{1, 1}';
GV_simInputOutputModelTest5InputsZscore_2(isnan(GV_simInputOutputModelTest5InputsZscore_2)) = 0;

%Calculate RMS error
RMSE_GasInputOutputModelTest5InputsZscore_2 = sqrt(mean((Qg_Test_2(2:160) - simGasInputOutputModelTest5InputsZscore_2{1,1}').^2));
RMSE_OilInputOutputModelTest5InputsZscore_2 = sqrt(mean((Qo_Test_2(2:160) - simOilInputOutputModelTest5InputsZscore_2{1,1}').^2));
RMSE_WatInputOutputModelTest5InputsZscore_2 = sqrt(mean((Qw_Test_2(2:160) - simWatInputOutputModelTest5InputsZscore_2{1,1}').^2));
RMSE_TotInputOutputModelTest5InputsZscore_2 = sqrt(mean((Qtot_Test_2(2:160) - simTotInputOutputModelTest5InputsZscore_2{1,1}').^2));
RMSE_GasNARXModelTest8InputsZscoreClosed_2 = sqrt(mean((Qg_Test_2(2:160) - simGasNARXModelTest8InputsZscoreClosed_2{1,1}').^2));
RMSE_OilNARXModelTest7InputsZscoreClosed_2 = sqrt(mean((Qo_Test_2(2:160) - simOilNARXModelTest7InputsZscoreClosed_2{1,1}').^2));
RMSE_WatNARXModelTest7InputsZscoreClosed_2 = sqrt(mean((Qw_Test_2(2:160) - simWatNARXModelTest7InputsZscoreClosed_2{1,1}').^2));
RMSE_TotNARXModelTest7InputsZscoreClosed_2 = sqrt(mean((Qtot_Test_2(2:160) - simTotNARXModelTest7InputsZscoreClosed_2{1,1}').^2));

%Setdiff

%------------------------------------------------------------------------------------------------------------------------------------------------------------------------

%Plots for data preparation
figure('Name','Voltage RMS of accelerometer samples in experiment G00');
plot(G00_2.testPoint.datAcc.ch(1).data(1:1*51200));
hold on
yline(rms(G00_2.testPoint.datAcc.ch(1).data(1*51200:2*51200)),'--k','Vrms value of 51200 samples','LineWidth',1);
xlim([1,51200]);
title('Voltage RMS of accelerometer samples in experiment G00');
legend('Accelerometer 1');
xlabel('Sample');
ylabel('V');

%Correlation plots
figure('Name','Correlation between differential pressure and flow');
corrplot([dataTrainAdj_2(:,2) dataTrainAdj_2(:,11:13) dataTrainAdj_2(:,16:18) dataTrainAdj_2(:,29) dataTrainAdj_2(:,25) dataTrainAdj_2(:,26) dataTrainAdj_2(:,27) dataTrainAdj_2(:,28)], VarNames=["wedge" "4mStr" "dp1V1" "dp2V1" "dp3V2" "dp1V2" "dp2V2" "totDp" "gasF" "watF" "oilF" "totF"]);
figure('Name','Correlation between accelerometers and flow');
corrplot([dataTrainAdj_2(:,21) dataTrainAdj_2(:,22) dataTrainAdj_2(:,23) dataTrainAdj_2(:,24) dataTrainAdj_2(:,25) dataTrainAdj_2(:,26) dataTrainAdj_2(:,27) dataTrainAdj_2(:,28)], VarNames=["acc1" "acc2" "acc3" "acc4" "gasF" "watF" "oilF" "totF"]);
figure('Name','Correlation between temperature and flow');
corrplot([dataTrainAdj_2(:,5) dataTrainAdj_2(:,19) dataTrainAdj_2(:,30) dataTrainAdj_2(:,25) dataTrainAdj_2(:,26) dataTrainAdj_2(:,27) dataTrainAdj_2(:,28)], VarNames=["innT" "outT" "gasF" "watF" "oilF" "totF" "dT"]);
figure('Name','Correlation between density, valve and flow');
corrplot([dataTrainAdj_2(:,1) dataTrainAdj_2(:,4) dataTrainAdj_2(:,8) dataTrainAdj_2(:,10) dataTrainAdj_2(:,14) dataTrainAdj_2(:,25) dataTrainAdj_2(:,26) dataTrainAdj_2(:,27) dataTrainAdj_2(:,28)], VarNames=["gam1" "denK4" "denE" "denK3" "gam2" "gasF" "watF" "oilF" "totF"]);

%Histogram for sample distribution
figure('Name','Sample distribution');
subplot(2,5,1);
histogram(dataTrainAdj_2(:,10));
title('density Krohn3');
subplot(2,5,2);
histogram(dataTrainAdj_2(:,11));
title('dp 4m straight');
subplot(2,5,3);
histogram(dataTrainAdj_2(:,17));
title('dp 1 Venturi 2');
subplot(2,5,4);
histogram(dataTrainAdj_2(:,18));
title('dp 2 Venturi 2');
subplot(2,5,5);
histogram(dataTrainAdj_2(:,29));
title('delta pressure');
subplot(2,5,6);
histogram(dataTrainAdj_2(:,21));
title('accelerometer 1');
subplot(2,5,7);
histogram(dataTrainAdj_2(:,22));
title('accelerometer 2');
subplot(2,5,8);
histogram(dataTrainAdj_2(:,23));
title('accelerometer 3');
subplot(2,5,9);
histogram(dataTrainAdj_2(:,24));
title('accelerometer 4');
subplot(2,5,10);
histogram(dataTrainAdj_2(:,30));
title('delta temperature');

%Linear scaling normalization of inputs
figure('Name','Linear scaling normalization of inputs');
subplot(2,1,1);
plot(dataTrainAdj_2(:,10),'g');
hold on
plot(dataTrainAdj_2(:,11),'y');
plot(dataTrainAdj_2(:,17),'c');
plot(dataTrainAdj_2(:,18),'m');
plot(dataTrainAdj_2(:,21),'k');
plot(dataTrainAdj_2(:,22),'k');
plot(dataTrainAdj_2(:,23),'k');
plot(dataTrainAdj_2(:,24),'k');
plot(dataTrainAdj_2(:,29),'r');
plot(dataTrainAdj_2(:,30),'b');
title('Original');
legend('density Krohn3','dp 4m straight','dp 1 Venturi 2','dp 2 Venturi 2','accelerometer 1','accelerometer 2','accelerometer 3','accelerometer 4','delta pressure','delta temperature');
xlabel('seconds');
ylabel('value');
subplot(2,1,2);
plot(trainLinear_2(:,10),'g');
hold on
plot(trainLinear_2(:,11),'y');
plot(trainLinear_2(:,17),'c');
plot(trainLinear_2(:,18),'m');
plot(trainLinear_2(:,21),'k');
plot(trainLinear_2(:,22),'k');
plot(trainLinear_2(:,23),'k');
plot(trainLinear_2(:,24),'k');
plot(trainLinear_2(:,29),'r');
plot(trainLinear_2(:,30),'b');
title('Linear scaling normalization of inputs');
legend('density Krohn3','dp 4m straight','dp 1 Venturi 2','dp 2 Venturi 2','accelerometer 1','accelerometer 2','accelerometer 3','accelerometer 4','delta pressure','delta temperature')
xlabel('seconds');
ylabel('value');

%Linear scaling normalization of inputs
figure('Name','Linear scaling normalization of inputs');
subplot(10,1,1);
plot(trainLinear_2(:,10),'g');
title('density Krohn3');
xlabel('seconds');
ylabel('value');
subplot(10,1,2);
plot(trainLinear_2(:,11),'y');
title('dp 4m straight');
xlabel('seconds');
ylabel('value');
subplot(10,1,3);
plot(trainLinear_2(:,17),'c');
title('dp 1 Venturi 2');
xlabel('seconds');
ylabel('value');
subplot(10,1,4);
plot(trainLinear_2(:,18),'m');
title('dp 2 Venturi 2');
xlabel('seconds');
ylabel('value');
subplot(10,1,5);
plot(trainLinear_2(:,21),'k');
title('accelerometer 1');
xlabel('seconds');
ylabel('value');
subplot(10,1,6);
plot(trainLinear_2(:,22),'k');
title('accelerometer 2');
xlabel('seconds');
ylabel('value');
subplot(10,1,7);
plot(trainLinear_2(:,23),'k');
title('accelerometer 3');
xlabel('seconds');
ylabel('value');
subplot(10,1,8);
plot(trainLinear_2(:,24),'k');
title('accelerometer 4');
xlabel('seconds');
ylabel('value');
subplot(10,1,9);
plot(trainLinear_2(:,29),'r');
title('delta pressure');
xlabel('seconds');
ylabel('value');
subplot(10,1,10);
plot(trainLinear_2(:,30),'b');
title('delta temperature');
xlabel('seconds');
ylabel('value');

%Z-score normalization of inputs
figure('Name','Z-score normalization of inputs');
subplot(2,1,1);
plot(dataTrainAdj_2(:,10),'g');
hold on
plot(dataTrainAdj_2(:,11),'y');
plot(dataTrainAdj_2(:,17),'c');
plot(dataTrainAdj_2(:,18),'m');
plot(dataTrainAdj_2(:,21),'k');
plot(dataTrainAdj_2(:,22),'k');
plot(dataTrainAdj_2(:,23),'k');
plot(dataTrainAdj_2(:,24),'k');
plot(dataTrainAdj_2(:,29),'r');
plot(dataTrainAdj_2(:,30),'b');
title('Original');
legend('density Krohn3','dp 4m straight','dp 1 Venturi 2','dp 2 Venturi 2','accelerometer 1','accelerometer 2','accelerometer 3','accelerometer 4','delta pressure','delta temperature');
xlabel('seconds');
ylabel('value');
subplot(2,1,2);
plot(trainZscore_2(:,10),'g');
hold on
plot(trainZscore_2(:,11),'y');
plot(trainZscore_2(:,17),'c');
plot(trainZscore_2(:,18),'m');
plot(trainZscore_2(:,21),'k');
plot(trainZscore_2(:,22),'k');
plot(trainZscore_2(:,23),'k');
plot(trainZscore_2(:,24),'k');
plot(trainZscore_2(:,29),'r');
plot(trainZscore_2(:,30),'b');
title('Normalized with z-score');
legend('density Krohn3','dp 4m straight','dp 1 Venturi 2','dp 2 Venturi 2','accelerometer 1','accelerometer 2','accelerometer 3','accelerometer 4','delta pressure','delta temperature')
xlabel('seconds');
ylabel('value');

%Z-score normalization of inputs
figure('Name','Z-score normalization of inputs');
subplot(10,1,1);
plot(trainZscore_2(:,10),'g');
title('density Krohn3');
xlabel('seconds');
ylabel('value');
subplot(10,1,2);
plot(trainZscore_2(:,11),'y');
title('dp 4m straight');
xlabel('seconds');
ylabel('value');
subplot(10,1,3);
plot(trainZscore_2(:,17),'c');
title('dp 1 Venturi 2');
xlabel('seconds');
ylabel('value');
subplot(10,1,4);
plot(trainZscore_2(:,18),'m');
title('dp 2 Venturi 2');
xlabel('seconds');
ylabel('value');
subplot(10,1,5);
plot(trainZscore_2(:,21),'k');
title('accelerometer 1');
xlabel('seconds');
ylabel('value');
subplot(10,1,6);
plot(trainZscore_2(:,22),'k');
title('accelerometer 2');
xlabel('seconds');
ylabel('value');
subplot(10,1,7);
plot(trainZscore_2(:,23),'k');
title('accelerometer 3');
xlabel('seconds');
ylabel('value');
subplot(10,1,8);
plot(trainZscore_2(:,24),'k');
title('accelerometer 4');
xlabel('seconds');
ylabel('value');
subplot(10,1,9);
plot(trainZscore_2(:,29),'r');
title('delta pressure');
xlabel('seconds');
ylabel('value');
subplot(10,1,10);
plot(trainZscore_2(:,30),'b');
title('delta temperature');
xlabel('seconds');
ylabel('value');

%Plots for gas flow models
figure('Name','Gas flow NARX model using 8 inputs and linear scaling normalization');
subplot(2,1,1)
plot(Qg_Train_2,'b');
hold on;
plot(simGasNARXModelTrain8InputsLinearOpen_2{1, 1},'r');
plot(simGasNARXModelTrain8InputsLinearClosed_2{1, 1},'k');
title('Model using training data from dataset2');
legend('Actual output','Opel loop estimate','Closed loop estimate');
xlabel('sample');
ylabel('flow [m3/h]');
subplot(2,1,2);
plot(Qg_Test_2,'b');
hold on;
plot(simGasNARXModelTest8InputsLinearOpen_2{1, 1},'r');
plot(simGasNARXModelTest8InputsLinearClosed_2{1, 1},'k');
title('Model using testing data from dataset2');
legend('Actual output','Opel loop estimate','Closed loop estimate');
xlabel('sample');
ylabel('flow [m3/h]');
figure('Name','Gas flow NARX model using 8 inputs and Z-score normalization');
subplot(2,1,1)
plot(Qg_Train_2,'b');
hold on;
plot(simGasNARXModelTrain8InputsZscoreOpen_2{1, 1},'r');
plot(simGasNARXModelTrain8InputsZscoreClosed_2{1, 1},'k');
title('Model using training data from dataset2');
legend('Actual output','Opel loop estimate','Closed loop estimate');
xlabel('sample');
ylabel('flow [m3/h]');
subplot(2,1,2);
plot(Qg_Test_2,'b');
hold on;
plot(simGasNARXModelTest8InputsZscoreOpen_2{1, 1},'r');
plot(simGasNARXModelTest8InputsZscoreClosed_2{1, 1},'k');
title('Model using testing data from dataset2');
legend('Actual output','Opel loop estimate','Closed loop estimate');
xlabel('sample');
ylabel('flow [m3/h]');
figure('Name','Gas flow delay model using 8 inputs and Z-score normalization');
subplot(2,1,1)
plot(Qg_Train_2,'b');
hold on;
plot(simGasInputOutputModelTrain8InputsZscore_2{1, 1},'r');
title('Model using training data from dataset2');
legend('Actual output','Estimated output');
xlabel('sample');
ylabel('flow [m3/h]');
subplot(2,1,2);
plot(Qg_Test_2,'b');
hold on;
plot(simGasInputOutputModelTest8InputsZscore_2{1, 1},'r');
title('Model using testing data from dataset2');
legend('Actual output','Estimated output');
xlabel('sample');
ylabel('flow [m3/h]');
ylim([-10,70]);
figure('Name','Gas flow delay model using 5 inputs and Z-score normalization');
subplot(2,1,1)
plot(Qg_Train_2,'b');
hold on;
plot(simGasInputOutputModelTrain5InputsZscore_2{1, 1},'r');
title('Model using training data from dataset2');
legend('Actual output','Estimated output');
xlabel('sample');
ylabel('flow [m3/h]');
subplot(2,1,2);
plot(Qg_Test_2,'b');
hold on;
plot(simGasInputOutputModelTest5InputsZscore_2{1, 1},'r');
title('Model using testing data from dataset2');
legend('Actual output','Estimated output');
xlabel('sample');
ylabel('flow [m3/h]');
ylim([-10,70]);

%Plots for oil flow models
figure('Name','Oil flow NARX model using 7 inputs and linear scaling');
subplot(2,1,1)
plot(Qo_Train_2,'b');
hold on;
plot(simOilNARXModelTrain7InputsLinearOpen_2{1, 1},'r');
plot(simOilNARXModelTrain7InputsLinearClosed_2{1, 1},'k');
title('Model using training data from dataset2');
legend('Actual output','Opel loop estimate','Closed loop estimate');
xlabel('sample');
ylabel('flow [m3/h]');
subplot(2,1,2);
plot(Qo_Test_2,'b');
plot(simOilNARXModelTest7InputsLinearOpen_2{1, 1},'r');
hold on;
plot(Qo_Test_2,'b');
plot(simOilNARXModelTest7InputsLinearClosed_2{1, 1},'k');
title('Model using testing data from dataset2');
legend('Actual output','Opel loop estimate','Closed loop estimate');
xlabel('sample');
ylabel('flow [m3/h]');

figure('Name','Oil flow NARX model using 7 inputs and Z-score');
subplot(2,1,1)
plot(Qo_Train_2,'b');
hold on;
plot(simOilNARXModelTrain7InputsZscoreOpen_2{1, 1},'r');
plot(simOilNARXModelTrain7InputsZscoreClosed_2{1, 1},'k');
title('Model using training data from dataset2');
legend('Actual output','Opel loop estimate','Closed loop estimate');
xlabel('sample');
ylabel('flow [m3/h]');
subplot(2,1,2);
plot(simOilNARXModelTest7InputsZscoreOpen_2{1, 1},'r');
hold on;
plot(Qo_Test_2,'b');
plot(simOilNARXModelTest7InputsZscoreClosed_2{1, 1},'k');
title('Model using testing data from dataset2');
legend('Actual output','Opel loop estimate','Closed loop estimate');
xlabel('sample');
ylabel('flow [m3/h]');
figure('Name','Oil flow delay model using 7 inputs and Z-score');
subplot(2,1,1)
plot(Qo_Train_2,'b');
hold on;
plot(simOilInputOutputModelTrain7InputsZscore_2{1, 1},'r');
title('Model using training data from dataset2');
legend('Actual output','Estimated output');
xlabel('sample');
ylabel('flow [m3/h]');
subplot(2,1,2);
plot(simOilInputOutputModelTest7InputsZscore_2{1, 1},'r');
hold on;
plot(Qo_Test_2,'b');
title('Model using testing data from dataset2');
legend('Actual output','Estimated output');
xlabel('sample');
ylabel('flow [m3/h]');
ylim([0,70]);
figure('Name','Oil flow delay model using 5 inputs and Z-score');
subplot(2,1,1)
plot(Qo_Train_2,'b');
hold on;
plot(simOilInputOutputModelTrain5InputsZscore_2{1, 1},'r');
title('Model using training data from dataset2');
legend('Actual output','Estimated output');
xlabel('sample');
ylabel('flow [m3/h]');
subplot(2,1,2);
plot(simOilInputOutputModelTest5InputsZscore_2{1, 1},'r');
hold on;
plot(Qo_Test_2,'b');
title('Model using testing data from dataset2');
legend('Actual output','Estimated output');
xlabel('sample');
ylabel('flow [m3/h]');
ylim([-10,70]);

%Plots for water flow models
figure('Name','Water flow NARX model using 7 inputs and linear scaling');
subplot(2,1,1)
plot(Qw_Train_2,'b');
hold on;
plot(simWatNARXModelTrain7InputsLinearOpen_2{1, 1},'r');
plot(simWatNARXModelTrain7InputsLinearClosed_2{1, 1},'k');
title('Model using training data from dataset2');
legend('Actual output','Opel loop estimate','Closed loop estimate');
xlabel('sample');
ylabel('flow [m3/h]');
subplot(2,1,2);
plot(Qw_Test_2,'b');
hold on;
plot(simWatNARXModelTest7InputsLinearOpen_2{1, 1},'r');
plot(simWatNARXModelTest7InputsLinearClosed_2{1, 1},'k');
title('Model using testing data from dataset2');
legend('Actual output','Opel loop estimate','Closed loop estimate');
xlabel('sample');
ylabel('flow [m3/h]');
figure('Name','Water flow model using 7 inputs and Z-score');
subplot(2,1,1)
plot(Qw_Train_2,'b');
hold on;
plot(simWatNARXModelTrain7InputsZscoreOpen_2{1, 1},'r');
plot(simWatNARXModelTrain7InputsZscoreClosed_2{1, 1},'k');
title('Model using training data from dataset2');
legend('Actual output','Opel loop estimate','Closed loop estimate');
xlabel('sample');
ylabel('flow [m3/h]');
subplot(2,1,2);
plot(Qw_Test_2,'b');
hold on;
plot(simWatNARXModelTest7InputsZscoreOpen_2{1, 1},'r');
plot(simWatNARXModelTest7InputsZscoreClosed_2{1, 1},'k');
title('Model using testing data from dataset2');
legend('Actual output','Opel loop estimate','Closed loop estimate');
xlabel('sample');
ylabel('flow [m3/h]');
figure('Name','Water flow NARX model using 7 inputs and Z-score');
subplot(2,1,1)
plot(Qw_Train_2,'b');
hold on;
plot(simWatNARXModelTrain7InputsZscoreOpen_2{1, 1},'r');
plot(simWatNARXModelTrain7InputsZscoreClosed_2{1, 1},'k');
title('Model using training data from dataset2');
legend('Actual output','Opel loop estimate','Closed loop estimate');
xlabel('sample');
ylabel('flow [m3/h]');
subplot(2,1,2);
plot(Qw_Test_2,'b');
hold on;
plot(simWatNARXModelTest7InputsZscoreOpen_2{1, 1},'r');
plot(simWatNARXModelTest7InputsZscoreClosed_2{1, 1},'k');
title('Model using testing data from dataset2');
legend('Actual output','Opel loop estimate','Closed loop estimate');
xlabel('sample');
ylabel('flow [m3/h]');
figure('Name','Water flow delay model using 7 inputs and Z-score');
subplot(2,1,1)
plot(Qw_Train_2,'b');
hold on;
plot(simWatInputOutputModelTrain7InputsZscore_2{1, 1},'r');
title('Model using training data from dataset2');
legend('Actual output','Estimated output');
xlabel('sample');
ylabel('flow [m3/h]');
subplot(2,1,2);
plot(Qw_Test_2,'b');
hold on;
plot(simWatInputOutputModelTest7InputsZscore_2{1, 1},'r');
title('Model using testing data from dataset2');
legend('Actual output','Estimated output');
xlabel('sample');
ylabel('flow [m3/h]');
figure('Name','Water flow delay model using 5 inputs and Z-score');
subplot(2,1,1)
plot(Qw_Train_2,'b');
hold on;
plot(simWatInputOutputModelTrain5InputsZscore_2{1, 1},'r');
title('Model using training data from dataset2');
legend('Actual output','Estimated output');
xlabel('sample');
ylabel('flow [m3/h]');
subplot(2,1,2);
plot(Qw_Test_2,'b');
hold on;
plot(simWatInputOutputModelTest5InputsZscore_2{1, 1},'r');
title('Model using testing data from dataset2');
legend('Actual output','Estimated output');
xlabel('sample');
ylabel('flow [m3/h]');

%Plots for total flow
figure('Name','Total flow NARX model using 7 inputs and linear scaling');
subplot(2,1,1)
plot(Qtot_Train_2,'b');
hold on;
plot(simTotNARXModelTrain7InputsLinearOpen_2{1, 1},'r');
plot(simTotNARXModelTrain7InputsLinearClosed_2{1, 1},'k');
title('Model using training data from dataset2');
legend('Actual output','Opel loop estimate','Closed loop estimate');
xlabel('sample');
ylabel('flow [m3/h]');
subplot(2,1,2);
plot(Qtot_Test_2,'b');
hold on;
plot(simTotNARXModelTest7InputsLinearOpen_2{1, 1},'r');
plot(simTotNARXModelTest7InputsLinearClosed_2{1, 1},'k');
title('Model using testing data from dataset2');
legend('Actual output','Opel loop estimate','Closed loop estimate');
xlabel('sample');
ylabel('flow [m3/h]');
figure('Name','Total flow NARX model using 7 inputs and Z-score');
subplot(2,1,1)
plot(Qtot_Train_2,'b');
hold on;
plot(simTotNARXModelTrain7InputsZscoreOpen_2{1, 1},'r');
plot(simTotNARXModelTrain7InputsZscoreClosed_2{1, 1},'k');
title('Model using training data from dataset2');
legend('Actual output','Opel loop estimate','Closed loop estimate');
xlabel('sample');
ylabel('flow [m3/h]');
subplot(2,1,2);
plot(Qtot_Test_2,'b');
hold on;
plot(simTotNARXModelTest7InputsZscoreOpen_2{1, 1},'r');
plot(simTotNARXModelTest7InputsZscoreClosed_2{1, 1},'k');
title('Model using testing data from dataset2');
legend('Actual output','Opel loop estimate','Closed loop estimate');
xlabel('sample');
ylabel('flow [m3/h]');
figure('Name','Total flow delay model using 7 inputs and Z-score');
subplot(2,1,1)
plot(Qtot_Train_2,'b');
hold on;
plot(simTotInputOutputModelTrain7InputsZscore_2{1, 1},'r');
title('Model using training data from dataset2');
legend('Actual output','Estimated output');
xlabel('sample');
ylabel('flow [m3/h]');
subplot(2,1,2);
plot(Qtot_Test_2,'b');
hold on;
plot(simTotInputOutputModelTest7InputsZscore_2{1, 1},'r');
title('Model using testing data from dataset2');
legend('Actual output','Estimated output');
xlabel('sample');
ylabel('flow [m3/h]');
ylim([0,120]);

figure('Name','Total flow delay model using 5 inputs and Z-score');
subplot(2,1,1)
plot(Qtot_Train_2,'b');
hold on;
plot(simTotInputOutputModelTrain5InputsZscore_2{1, 1},'r');
title('Model using training data from dataset2');
legend('Actual output','Estimated output');
xlabel('sample');
ylabel('flow [m3/h]');
subplot(2,1,2);
plot(Qtot_Test_2,'b');
hold on;
plot(simTotInputOutputModelTest5InputsZscore_2{1, 1},'r');
title('Model using testing data from dataset2');
legend('Actual output','Estimated output');
xlabel('sample');
ylabel('flow [m3/h]');
ylim([-20,120]);

%Water cut
figure('Name','Water Liquid Ratio');
subplot(2,1,1);
plot(WLR_Train_2,'b');
hold on;
plot(WLR_simInputOutputModelTrain7InputsZscore_2, 'r');
legend('Actual','Estimated');
title('Estimated WLR using 7 inputs from training data in dataset2');
ylim([-1 1]);
xlabel('samples');
ylabel('WLR')
subplot(2,1,2);
plot(WLR_Train_2,'b');
hold on;
plot(WLR_simInputOutputModelTrain5InputsZscore_2, 'r');
legend('Actual','Estimated');
title('Estimated WLR using 5 inputs from from training data in dataset2');
ylim([-1 1]);
xlabel('samples');
ylabel('WLR')

%Gas void fraction
figure('Name','Gas Volume Fraction');
subplot(2,1,1);
plot(GV_Train_2,'b');
hold on;
plot(GV_simInputOutputModelTrain7InputsZscore_2, 'r');
legend('Actual','Estimated');
title('Estimated GVF using 7 inputs from training data in dataset2');
xlabel('sample');
ylim([-1.5 1])
ylabel('GVF')
subplot(2,1,2);
plot(GV_Train_2,'b');
hold on;
plot(GV_simInputOutputModelTrain5InputsZscore_2, 'r');
legend('Actual','Estimated');
title('Estimated GVF fraction using 5 inputs from training data in dataset2');
xlabel('samples');
ylim([-1.5 1]);
ylabel('GVF')

%Results plot
figure('Name',' Overview of the results');
subplot(6,1,1);
plot(Qg_Test_2,'b');
hold on;
plot(max(0, simGasInputOutputModelTest5InputsZscore_2{1, 1}),'r');
title('Nonlinear input-output network for gas flowrate using 5 inputs from testing data and Z-score normalization');
legend('Actual','Estimated');
xlabel('sample');
ylabel('flow [m3/h]');
ylim([-10,70]);
subplot(6,1,2);
plot(Qw_Test_2,'b');
hold on;
plot(max(0, simWatInputOutputModelTest5InputsZscore_2{1, 1}),'r');
title('Nonlinear input-output network for water flowrate using 5 inputs from testing data and Z-score');
legend('Actual','Estimated');
xlabel('sample');
ylabel('flow [m3/h]');
ylim([-10,50]);
subplot(6,1,3);
plot(Qo_Test_2,'b');
hold on;
plot(max(0, simOilInputOutputModelTest5InputsZscore_2{1, 1}),'r');
title('Nonlinear input-output network for oil flowrate using 5 inputs from testingdata and Z-score');
legend('Actual','Estimated');
xlabel('sample');
ylabel('flow [m3/h]');
ylim([-10,60]);
subplot(6,1,4);
plot(Qtot_Test_2,'b');
hold on;
plot(max(0, simTotInputOutputModelTest5InputsZscore_2{1, 1}),'r');
title('Nonlinear input-output network for total flowrate model using 5 inputs and Z-score normalization');
legend('Actual','Estimated');
xlabel('sample');
ylabel('flow [m3/h]');
ylim([-10,150]);
subplot(6,1,5)
plot(WLR_Test_2,'b');
hold on;
plot(max(0, WLR_simInputOutputModelTest5InputsZscore_2),'r');
title('Estimated WLR using testing data from dataset2');
legend('Actual','Estimated');
xlabel('sample');
ylabel('WLR');
ylim([-0.1,1.4]);
subplot(6,1,6)
plot(GV_Test_2,'b');
hold on;
plot(max(0, GV_simInputOutputModelTest5InputsZscore_2),'r');
title('Estimated GVF using training data from dataset2');
legend('Actual','Estimated');
xlabel('sample');
ylabel('GVF');
ylim([-0.1,0.7]);



%------------------------------------------------------------------------------------------------------------------------------------------------------------------------

%Function for preparing data before network simulation

function y = SimulateNARXNetwork(network, inputData, outputData)
    [Xs,Xi, Ai] = preparets(network, inputData, {}, outputData);
    y = sim(network, Xs, Xi, Ai);
end

function y = SimulateInputOutputNetwork(network, inputData, outputData)
    [Xs,Xi, Ai] = preparets(network, inputData, outputData);
    y = sim(network, Xs, Xi, Ai);
end


